package com.iamberry.cms.face.milk;

import java.util.List;

import com.iamberry.cms.core.dto.MilkPowderInfoDto;
import com.iamberry.cms.core.entity.MilkPowderInfo;

/**
 * 奶粉信息 service
 * 2016年12月12日
 * 穆再兴
 * @author Administrator
 *
 */
public interface MilkPowderService {
	/**
	 * 查询所有奶粉信息列表
	 * 2016年12月12日
	 * 穆再兴
	 * @param milkPowderDto
	 * @return
	 */
	public List<MilkPowderInfo> selectMilkPowderList(MilkPowderInfoDto milkPowderDto);
	
	/**
	 * 查询符合条件的所有奶粉信息总数
	 * 2016年12月12日
	 * 穆再兴
	 * @param milkPowderDto
	 * @return
	 */
	public Integer selectMilkPowderCount(MilkPowderInfoDto milkPowderDto);

	/**
	 * 根据id查询一个奶粉信息
	 * 2016年12月12日
	 * 穆再兴
	 * @param milkPowderDto
	 * @return
	 */
	public MilkPowderInfo selectMilkPowderInfoById(Integer id);
	/**
	 * 添加一个奶粉信息
	 * 2016年12月13日
	 * 穆再兴
	 * @param milkPowderInfo
	 * @return
	 */
	public Integer insertMilkPowderInfo(MilkPowderInfo milkPowderInfo);
	
	/**
	 * 根据id修改一个奶粉信息
	 * 2016年12月13日
	 * 穆再兴
	 * @param milkPowderInfo
	 * @return
	 */
	public Integer updateMilkPowderInfoById(MilkPowderInfo milkPowderInfo);
	
	/**
	 * 根据id删除一个奶粉信息
	 * 2016年12月13日
	 * 穆再兴
	 * @param milkPowderInfo
	 * @return
	 */
	public Integer deleteMilkPowderInfoById(Integer id);
	/**
	 * 根据条形码查询一个奶粉信息
	 * 2017年3月14日11:19:25
	 * LJK
	 * @param milkPowderDto
	 * @return
	 */
	public Integer selectMilkPowderInfoByCode(MilkPowderInfo milkPowderInfo);
}
